Learn R Programming

gTestsPair (version 0.1)

getMV_pair: Get intermediate results for g.tests_pair function

Description

This function calculates means and variances of R1 and R2 quantities under the paired- comparison permutation null.

Usage

getMV_pair(E,n)

Arguments

E

An edge matrix representing a similarity graph on all observations with the number of edges in the similarity graph being the number of rows and 2 columns. Each row records the indices of the two ends of an edge in the similarity graph.

n

The number of pairs.

See Also

g.tests_pair