This function calculates means and variances of R1 and R2 quantities under the paired- comparison permutation null.
getMV_pair(E,n)
An edge matrix representing a similarity graph on all observations with the number of edges in the similarity graph being the number of rows and 2 columns. Each row records the indices of the two ends of an edge in the similarity graph.
The number of pairs.
g.tests_pair