getR1R2_pair: Get intermediate results for g.tests_pair function
Description
This function calculates R1 and R2 quantities.
Usage
getR1R2_pair(E,group1)
Arguments
E
An edge matrix representing a similarity graph on all observations with the number of edges in the similarity graph being the number of rows and 2 columns. Each row records the indices of the two ends of an edge in the similarity graph.